# Instructions

#### This is our test project. 

#### Please install this package
```
pip install functions-by-krystsinali
```


#### You can also install older packages
```
pip install functions-by-krystsinali==VERSION_NUMBER
```